"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateConfiguration = exports.getConfiguration = void 0;
const config_interface_1 = require("./config.interface");
const lodash_1 = require("lodash");
const class_validator_1 = require("class-validator");
const class_transformer_1 = require("class-transformer");
exports.getConfiguration = lodash_1.memoize(() => ({
    CERTIFICATE_QUEUE_DELAY: process.env.CERTIFICATE_QUEUE_DELAY
        ? parseInt(process.env.CERTIFICATE_QUEUE_DELAY, 10)
        : 10000,
    ISSUER_PRIVATE_KEY: process.env.ISSUER_PRIVATE_KEY,
    WEB3: {
        primaryRPC: process.env.WEB3?.split(';')?.[0],
        fallbackRPC: process.env.WEB3?.split(';')?.[1]
    },
    BLOCKCHAIN_POLLING_INTERVAL: process.env.BLOCKCHAIN_POLLING_INTERVAL
        ? parseInt(process.env.BLOCKCHAIN_POLLING_INTERVAL, 10)
        : undefined,
    CERTIFICATE_QUEUE_LOCK_DURATION: Number(process.env.CERTIFICATE_QUEUE_LOCK_DURATION ?? 240 * 1000)
}));
const validateConfiguration = async () => {
    const configValues = exports.getConfiguration();
    await class_validator_1.validateOrReject(class_transformer_1.plainToClass(config_interface_1.OnchainConfiguration, configValues));
};
exports.validateConfiguration = validateConfiguration;
//# sourceMappingURL=configuration.js.map